==> brmo-stufbg204-1.5.0-sources.jar: nl/egem/stuf/sector/bg/_0204/VBOAntwoord.java <==

package nl.egem.stuf.sector.bg._0204;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;


/**
 * verblijfsobject binnen antwoordbericht
 * 
 * <p>Java class for VBO-antwoord complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="VBO-antwoord">
 *   &lt;complexContent>
 *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}VBO-fund">
 *       &lt;sequence>
 *         &lt;element name="VBO" type="{http://www.egem.nl/StUF/sector/bg/0204}VBO-fund" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="VBOADR" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-relFund" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="VBOBSG" maxOccurs="unbounded" minOccurs="0">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
 *                 &lt;sequence>
 *                   &lt;element name="BSG" type="{http://www.egem.nl/StUF/sector/bg/0204}BSG-fund"/>
 *                 &lt;/sequence>
 *               &lt;/extension>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *         &lt;element name="VBOKDO" maxOccurs="unbounded" minOccurs="0">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
 *                 &lt;sequence>
 *                   &lt;element name="KDO" type="{http://www.egem.nl/StUF/sector/bg/0204}KDO-kennisgeving"/>
 *                 &lt;/sequence>
 *               &lt;/extension>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *         &lt;element name="VBOSUBGBR" maxOccurs="unbounded" minOccurs="0">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
 *                 &lt;choice>
 *                   &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kennisgeving"/>
 *                   &lt;element name="PRS" type="{http://www.egem.nl/StUF/sector/bg/0204}PRS-kennisgeving"/>
 *                 &lt;/choice>
 *               &lt;/extension>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *         &lt;element name="VBOVBOOSU" maxOccurs="unbounded" minOccurs="0">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}VBOVBOOSU-rel">
 *                 &lt;sequence>
 *                   &lt;element name="VBO" type="{http://www.egem.nl/StUF/sector/bg/0204}VBO-kennisgeving"/>
 *                 &lt;/sequence>
 *               &lt;/extension>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "VBO-antwoord", propOrder = {
    "vbo",
    "vboadr",
    "vbobsg",
    "vbokdo",
    "vbosubgbr",
    "vbovboosu"
})
public class VBOAntwoord
    extends VBOFund
{

    @XmlElement(name = "VBO")
    protected List<VBOFund> vbo;
    @XmlElement(name = "VBOADR", nillable = true)
    protected List<ADRRelFund> vboadr;
    @XmlElement(name = "VBOBSG", nillable = true)
    protected List<VBOAntwoord.VBOBSG> vbobsg;
    @XmlElement(name = "VBOKDO", nillable = true)
    protected List<VBOAntwoord.VBOKDO> vbokdo;
    @XmlElement(name = "VBOSUBGBR", nillable = true)
    protected List<VBOAntwoord.VBOSUBGBR> vbosubgbr;
    @XmlElement(name = "VBOVBOOSU", nillable = true)
    protected List<VBOAntwoord.VBOVBOOSU> vbovboosu;

    /**
     * Gets the value of the vbo property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the vbo property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVBO().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link VBOFund }
     * 
     * 
     */
    public List<VBOFund> getVBO() {
        if (vbo == null) {
            vbo = new ArrayList<VBOFund>();
        }
        return this.vbo;
    }

    /**
     * Gets the value of the vboadr property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the vboadr property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVBOADR().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ADRRelFund }
     * 
     * 
     */
    public List<ADRRelFund> getVBOADR() {
        if (vboadr == null) {
            vboadr = new ArrayList<ADRRelFund>();
        }
        return this.vboadr;
    }

    /**
     * Gets the value of the vbobsg property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the vbobsg property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVBOBSG().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link VBOAntwoord.VBOBSG }
     * 
     * 
     */
    public List<VBOAntwoord.VBOBSG> getVBOBSG() {
        if (vbobsg == null) {
            vbobsg = new ArrayList<VBOAntwoord.VBOBSG>();
        }
        return this.vbobsg;
    }

    /**
     * Gets the value of the vbokdo property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the vbokdo property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVBOKDO().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link VBOAntwoord.VBOKDO }
     * 
     * 
     */
    public List<VBOAntwoord.VBOKDO> getVBOKDO() {
        if (vbokdo == null) {
            vbokdo = new ArrayList<VBOAntwoord.VBOKDO>();
        }
        return this.vbokdo;
    }

    /**
     * Gets the value of the vbosubgbr property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the vbosubgbr property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVBOSUBGBR().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link VBOAntwoord.VBOSUBGBR }
     * 
     * 
     */
    public List<VBOAntwoord.VBOSUBGBR> getVBOSUBGBR() {
        if (vbosubgbr == null) {
            vbosubgbr = new ArrayList<VBOAntwoord.VBOSUBGBR>();
        }
        return this.vbosubgbr;
    }

    /**
     * Gets the value of the vbovboosu property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the vbovboosu property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVBOVBOOSU().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link VBOAntwoord.VBOVBOOSU }
     * 
     * 
     */
    public List<VBOAntwoord.VBOVBOOSU> getVBOVBOOSU() {
        if (vbovboosu == null) {
            vbovboosu = new ArrayList<VBOAntwoord.VBOVBOOSU>();
        }
        return this.vbovboosu;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
     *       &lt;sequence>
     *         &lt;element name="BSG" type="{http://www.egem.nl/StUF/sector/bg/0204}BSG-fund"/>
     *       &lt;/sequence>
     *     &lt;/extension>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "bsg"
    })
    public static class VBOBSG
        extends Relatie
    {

        @XmlElement(name = "BSG", required = true, nillable = true)
        protected BSGFund bsg;

        /**
         * Gets the value of the bsg property.
         * 
         * @return
         *     possible object is
         *     {@link BSGFund }
         *     
         */
        public BSGFund getBSG() {
            return bsg;
        }

        /**
         * Sets the value of the bsg property.
         * 
         * @param value
         *     allowed object is
         *     {@link BSGFund }
         *     
         */
        public void setBSG(BSGFund value) {
            this.bsg = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
     *       &lt;sequence>
     *         &lt;element name="KDO" type="{http://www.egem.nl/StUF/sector/bg/0204}KDO-kennisgeving"/>
     *       &lt;/sequence>
     *     &lt;/extension>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "kdo"
    })
    public static class VBOKDO
        extends Relatie
    {

        @XmlElement(name = "KDO", required = true, nillable = true)
        protected KDOKennisgeving kdo;

        /**
         * Gets the value of the kdo property.
         * 
         * @return
         *     possible object is
         *     {@link KDOKennisgeving }
         *     
         */
        public KDOKennisgeving getKDO() {
            return kdo;
        }

        /**
         * Sets the value of the kdo property.
         * 
         * @param value
         *     allowed object is
         *     {@link KDOKennisgeving }
         *     
         */
        public void setKDO(KDOKennisgeving value) {
            this.kdo = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
     *       &lt;choice>
     *         &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kennisgeving"/>
     *         &lt;element name="PRS" type="{http://www.egem.nl/StUF/sector/bg/0204}PRS-kennisgeving"/>
     *       &lt;/choice>
     *     &lt;/extension>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "nnp",
        "prs"
    })
    public static class VBOSUBGBR
        extends Relatie
    {

        @XmlElementRef(name = "NNP", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
        protected JAXBElement<NNPKennisgeving> nnp;
        @XmlElementRef(name = "PRS", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
        protected JAXBElement<PRSKennisgeving> prs;

        /**
         * Gets the value of the nnp property.
         * 
         * @return
         *     possible object is
         *     {@link JAXBElement }{@code <}{@link NNPKennisgeving }{@code >}
         *     
         */
        public JAXBElement<NNPKennisgeving> getNNP() {
            return nnp;
        }

        /**
         * Sets the value of the nnp property.
         * 
         * @param value
         *     allowed object is
         *     {@link JAXBElement }{@code <}{@link NNPKennisgeving }{@code >}
         *     
         */
        public void setNNP(JAXBElement<NNPKennisgeving> value) {
            this.nnp = value;
        }

        /**
         * Gets the value of the prs property.
         * 
         * @return
         *     possible object is
         *     {@link JAXBElement }{@code <}{@link PRSKennisgeving }{@code >}
         *     
         */
        public JAXBElement<PRSKennisgeving> getPRS() {
            return prs;
        }

        /**
         * Sets the value of the prs property.
         * 
         * @param value
         *     allowed object is
         *     {@link JAXBElement }{@code <}{@link PRSKennisgeving }{@code >}
         *     
         */
        public void setPRS(JAXBElement<PRSKennisgeving> value) {
            this.prs = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}VBOVBOOSU-rel">
     *       &lt;sequence>
     *         &lt;element name="VBO" type="{http://www.egem.nl/StUF/sector/bg/0204}VBO-kennisgeving"/>
     *       &lt;/sequence>
     *     &lt;/extension>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "vbo"
    })
    public static class VBOVBOOSU
        extends VBOVBOOSURel
    {

        @XmlElement(name = "VBO", required = true, nillable = true)
        protected VBOKennisgeving vbo;

        /**
         * Gets the value of the vbo property.
         * 
         * @return
         *     possible object is
         *     {@link VBOKennisgeving }
         *     
         */
        public VBOKennisgeving getVBO() {
            return vbo;
        }

        /**
         * Sets the value of the vbo property.
         * 
         * @param value
         *     allowed object is
         *     {@link VBOKennisgeving }
         *     
         */
        public void setVBO(VBOKennisgeving value) {
            this.vbo = value;
        }

    }

}

==> brmo-stufbg204-2.0.0-sources.jar: nl/egem/stuf/sector/bg/_0204/VBOAntwoord.java <==

package nl.egem.stuf.sector.bg._0204;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;


/**
 * verblijfsobject binnen antwoordbericht
 * 
 * <p>Java class for VBO-antwoord complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="VBO-antwoord"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}VBO-fund"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="VBO" type="{http://www.egem.nl/StUF/sector/bg/0204}VBO-fund" maxOccurs="unbounded" minOccurs="0"/&gt;
 *         &lt;element name="VBOADR" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-relFund" maxOccurs="unbounded" minOccurs="0"/&gt;
 *         &lt;element name="VBOBSG" maxOccurs="unbounded" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
 *                 &lt;sequence&gt;
 *                   &lt;element name="BSG" type="{http://www.egem.nl/StUF/sector/bg/0204}BSG-fund"/&gt;
 *                 &lt;/sequence&gt;
 *               &lt;/extension&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="VBOKDO" maxOccurs="unbounded" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
 *                 &lt;sequence&gt;
 *                   &lt;element name="KDO" type="{http://www.egem.nl/StUF/sector/bg/0204}KDO-kennisgeving"/&gt;
 *                 &lt;/sequence&gt;
 *               &lt;/extension&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="VBOSUBGBR" maxOccurs="unbounded" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
 *                 &lt;choice&gt;
 *                   &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kennisgeving"/&gt;
 *                   &lt;element name="PRS" type="{http://www.egem.nl/StUF/sector/bg/0204}PRS-kennisgeving"/&gt;
 *                 &lt;/choice&gt;
 *               &lt;/extension&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="VBOVBOOSU" maxOccurs="unbounded" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}VBOVBOOSU-rel"&gt;
 *                 &lt;sequence&gt;
 *                   &lt;element name="VBO" type="{http://www.egem.nl/StUF/sector/bg/0204}VBO-kennisgeving"/&gt;
 *                 &lt;/sequence&gt;
 *               &lt;/extension&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "VBO-antwoord", propOrder = {
    "vbo",
    "vboadr",
    "vbobsg",
    "vbokdo",
    "vbosubgbr",
    "vbovboosu"
})
public class VBOAntwoord
    extends VBOFund
{

    @XmlElement(name = "VBO")
    protected List<VBOFund> vbo;
    @XmlElement(name = "VBOADR", nillable = true)
    protected List<ADRRelFund> vboadr;
    @XmlElement(name = "VBOBSG", nillable = true)
    protected List<VBOAntwoord.VBOBSG> vbobsg;
    @XmlElement(name = "VBOKDO", nillable = true)
    protected List<VBOAntwoord.VBOKDO> vbokdo;
    @XmlElement(name = "VBOSUBGBR", nillable = true)
    protected List<VBOAntwoord.VBOSUBGBR> vbosubgbr;
    @XmlElement(name = "VBOVBOOSU", nillable = true)
    protected List<VBOAntwoord.VBOVBOOSU> vbovboosu;

    /**
     * Gets the value of the vbo property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the vbo property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVBO().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link VBOFund }
     * 
     * 
     */
    public List<VBOFund> getVBO() {
        if (vbo == null) {
            vbo = new ArrayList<VBOFund>();
        }
        return this.vbo;
    }

    /**
     * Gets the value of the vboadr property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the vboadr property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVBOADR().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ADRRelFund }
     * 
     * 
     */
    public List<ADRRelFund> getVBOADR() {
        if (vboadr == null) {
            vboadr = new ArrayList<ADRRelFund>();
        }
        return this.vboadr;
    }

    /**
     * Gets the value of the vbobsg property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the vbobsg property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVBOBSG().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link VBOAntwoord.VBOBSG }
     * 
     * 
     */
    public List<VBOAntwoord.VBOBSG> getVBOBSG() {
        if (vbobsg == null) {
            vbobsg = new ArrayList<VBOAntwoord.VBOBSG>();
        }
        return this.vbobsg;
    }

    /**
     * Gets the value of the vbokdo property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the vbokdo property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVBOKDO().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link VBOAntwoord.VBOKDO }
     * 
     * 
     */
    public List<VBOAntwoord.VBOKDO> getVBOKDO() {
        if (vbokdo == null) {
            vbokdo = new ArrayList<VBOAntwoord.VBOKDO>();
        }
        return this.vbokdo;
    }

    /**
     * Gets the value of the vbosubgbr property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the vbosubgbr property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVBOSUBGBR().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link VBOAntwoord.VBOSUBGBR }
     * 
     * 
     */
    public List<VBOAntwoord.VBOSUBGBR> getVBOSUBGBR() {
        if (vbosubgbr == null) {
            vbosubgbr = new ArrayList<VBOAntwoord.VBOSUBGBR>();
        }
        return this.vbosubgbr;
    }

    /**
     * Gets the value of the vbovboosu property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the vbovboosu property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVBOVBOOSU().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link VBOAntwoord.VBOVBOOSU }
     * 
     * 
     */
    public List<VBOAntwoord.VBOVBOOSU> getVBOVBOOSU() {
        if (vbovboosu == null) {
            vbovboosu = new ArrayList<VBOAntwoord.VBOVBOOSU>();
        }
        return this.vbovboosu;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
     *       &lt;sequence&gt;
     *         &lt;element name="BSG" type="{http://www.egem.nl/StUF/sector/bg/0204}BSG-fund"/&gt;
     *       &lt;/sequence&gt;
     *     &lt;/extension&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "bsg"
    })
    public static class VBOBSG
        extends Relatie
    {

        @XmlElement(name = "BSG", required = true, nillable = true)
        protected BSGFund bsg;

        /**
         * Gets the value of the bsg property.
         * 
         * @return
         *     possible object is
         *     {@link BSGFund }
         *     
         */
        public BSGFund getBSG() {
            return bsg;
        }

        /**
         * Sets the value of the bsg property.
         * 
         * @param value
         *     allowed object is
         *     {@link BSGFund }
         *     
         */
        public void setBSG(BSGFund value) {
            this.bsg = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
     *       &lt;sequence&gt;
     *         &lt;element name="KDO" type="{http://www.egem.nl/StUF/sector/bg/0204}KDO-kennisgeving"/&gt;
     *       &lt;/sequence&gt;
     *     &lt;/extension&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "kdo"
    })
    public static class VBOKDO
        extends Relatie
    {

        @XmlElement(name = "KDO", required = true, nillable = true)
        protected KDOKennisgeving kdo;

        /**
         * Gets the value of the kdo property.
         * 
         * @return
         *     possible object is
         *     {@link KDOKennisgeving }
         *     
         */
        public KDOKennisgeving getKDO() {
            return kdo;
        }

        /**
         * Sets the value of the kdo property.
         * 
         * @param value
         *     allowed object is
         *     {@link KDOKennisgeving }
         *     
         */
        public void setKDO(KDOKennisgeving value) {
            this.kdo = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
     *       &lt;choice&gt;
     *         &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kennisgeving"/&gt;
     *         &lt;element name="PRS" type="{http://www.egem.nl/StUF/sector/bg/0204}PRS-kennisgeving"/&gt;
     *       &lt;/choice&gt;
     *     &lt;/extension&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "nnp",
        "prs"
    })
    public static class VBOSUBGBR
        extends Relatie
    {

        @XmlElementRef(name = "NNP", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
        protected JAXBElement<NNPKennisgeving> nnp;
        @XmlElementRef(name = "PRS", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
        protected JAXBElement<PRSKennisgeving> prs;

        /**
         * Gets the value of the nnp property.
         * 
         * @return
         *     possible object is
         *     {@link JAXBElement }{@code <}{@link NNPKennisgeving }{@code >}
         *     
         */
        public JAXBElement<NNPKennisgeving> getNNP() {
            return nnp;
        }

        /**
         * Sets the value of the nnp property.
         * 
         * @param value
         *     allowed object is
         *     {@link JAXBElement }{@code <}{@link NNPKennisgeving }{@code >}
         *     
         */
        public void setNNP(JAXBElement<NNPKennisgeving> value) {
            this.nnp = value;
        }

        /**
         * Gets the value of the prs property.
         * 
         * @return
         *     possible object is
         *     {@link JAXBElement }{@code <}{@link PRSKennisgeving }{@code >}
         *     
         */
        public JAXBElement<PRSKennisgeving> getPRS() {
            return prs;
        }

        /**
         * Sets the value of the prs property.
         * 
         * @param value
         *     allowed object is
         *     {@link JAXBElement }{@code <}{@link PRSKennisgeving }{@code >}
         *     
         */
        public void setPRS(JAXBElement<PRSKennisgeving> value) {
            this.prs = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}VBOVBOOSU-rel"&gt;
     *       &lt;sequence&gt;
     *         &lt;element name="VBO" type="{http://www.egem.nl/StUF/sector/bg/0204}VBO-kennisgeving"/&gt;
     *       &lt;/sequence&gt;
     *     &lt;/extension&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "vbo"
    })
    public static class VBOVBOOSU
        extends VBOVBOOSURel
    {

        @XmlElement(name = "VBO", required = true, nillable = true)
        protected VBOKennisgeving vbo;

        /**
         * Gets the value of the vbo property.
         * 
         * @return
         *     possible object is
         *     {@link VBOKennisgeving }
         *     
         */
        public VBOKennisgeving getVBO() {
            return vbo;
        }

        /**
         * Sets the value of the vbo property.
         * 
         * @param value
         *     allowed object is
         *     {@link VBOKennisgeving }
         *     
         */
        public void setVBO(VBOKennisgeving value) {
            this.vbo = value;
        }

    }

}
